[GRASS-SVN] r73005 - grass/trunk/lib/ogsf

svn_grass at osgeo.org svn_grass at osgeo.org
Wed Jul 25 13:35:14 PDT 2018


Author: hcho
Date: 2018-07-25 13:35:14 -0700 (Wed, 25 Jul 2018)
New Revision: 73005

Modified:
   grass/trunk/lib/ogsf/gsd_views.c
Log:
ogsf: Use GS_set_draw instead of glDrawBuffer

Modified: grass/trunk/lib/ogsf/gsd_views.c
===================================================================
--- grass/trunk/lib/ogsf/gsd_views.c	2018-07-25 20:17:24 UTC (rev 73004)
+++ grass/trunk/lib/ogsf/gsd_views.c	2018-07-25 20:35:14 UTC (rev 73005)
@@ -66,7 +66,7 @@
     vect[TO][Z] = tz;
 
     /* DEBUG - should just be a dot */
     /* OGLXXX frontbuffer: other possibilities include GL_FRONT_AND_BACK */
     GS_set_draw((1) ? GSD_FRONT : GSD_BACK);
     glPushMatrix();
     gsd_do_scale(1);
@@ -82,8 +82,8 @@
     gsd_linewidth(1);
     glPopMatrix();
 
-    /* OGLXXX frontbuffer: other possibilities include GL_FRONT_AND_BACK */
-    GS_set_draw((0) ? GL_FRONT : GL_BACK);
+    /* OGLXXX frontbuffer: other possibilities include GSD_BOTH */
+    GS_set_draw((0) ? GSD_FRONT : GSD_BACK);
 
     return (1);
 }
@@ -66,7 +66,7 @@
 
     /* DEBUG - should just be a dot */
-    /* OGLXXX frontbuffer: other possibilities include GL_FRONT_AND_BACK */
+    /* OGLXXX frontbuffer: other possibilities include GSD_BOTH */
     GS_set_draw((1) ? GSD_FRONT : GSD_BACK);
     glPushMatrix();



More information about the grass-commit mailing list